summaryrefslogtreecommitdiff
path: root/actions/api.php
diff options
context:
space:
mode:
Diffstat (limited to 'actions/api.php')
-rw-r--r--actions/api.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/actions/api.php b/actions/api.php
index 897e848c1..91f30e87a 100644
--- a/actions/api.php
+++ b/actions/api.php
@@ -125,9 +125,9 @@ class ApiAction extends Action
'users/show',
'help/test',
'help/downtime_schedule',
- 'laconica/version',
- 'laconica/config',
- 'laconica/wadl',
+ 'statusnet/version',
+ 'statusnet/config',
+ 'statusnet/wadl',
'tags/timeline',
'oembed/oembed',
'groups/show',
@@ -147,11 +147,11 @@ class ApiAction extends Action
$fullname = "$this->api_action/$this->api_method";
// If the site is "private", all API methods except laconica/config
// need authentication
if (common_config('site', 'private')) {
- return $fullname != 'laconica/config' || false;
+ return $fullname != 'statusnet/config' || false;
}
// bareauth: only needs auth if without an argument or query param specifying user
@@ -147,11 +147,11 @@ class ApiAction extends Action
$fullname = "$this->api_action/$this->api_method";
- // If the site is "private", all API methods except laconica/config
+ // If the site is "private", all API methods except statusnet/config
// need authentication
if (common_config('site', 'private')) {